; docformat = 'rst'
;+
; This is an example program to demontrate how to create a bar plot with multiple sets of bars
; with Coyote Graphics routines.
;
; :Categories:
;    Graphics
;    
; :Examples:
;    Save the program as "multibar_plot.pro" and run it like this::
;       IDL> .RUN multibar_plot
;       
; :Author:
;    FANNING SOFTWARE CONSULTING::
;       David W. Fanning 
;       1645 Sheely Drive
;       Fort Collins, CO 80526 USA
;       Phone: 970-221-0438
;       E-mail: david@idlcoyote.com
;       Coyote's Guide to IDL Programming: http://www.idlcoyote.com
;
; :History:
;     Change History::
;        Written, 23 January 2013 by David W. Fanning.
;
; :Copyright:
;     Copyright (c) 2013, Fanning Software Consulting, Inc.
;-
PRO MultiBar_Plot
 
   ; Create data and labels for the bar plot. Normally, this information
   ; is passed into the programs a positional and keyword parameters.
   seed = -5L
   data1 = RandomU(seed, 4) * 10.0
   data2 = RandomU(seed, 4) * 7.5
   data3 = RandomU(seed, 4) * 7.5
   data4 = RandomU(seed, 4) * 10.0   
   labels = ['Run 1',    'Run 2',   'Run 3',  'Run 4'    ]
   items =  ['Class 1', 'Class 2', 'Class 3', 'Class 4'  ]
   colors = ['red',      'blue',    'gold',  'dark green']   
   IF Total(!P.Position) EQ 0 THEN position=[0.125, 0.125, 0.9, 0.9] ELSE position = !P.Position

   ; Draw the overlapping bar plots.
   cgDisplay
   cgErase
   cgColorFill, Position=position, Color='linen'
   cgBarPlot, data1, YRange=[0,35], Colors='red', BarNames=labels, $
      Position=position, /NoErase, YTitle='Percentage of Bad Lots', $
      XTitle='Production Number'
   cgBarPlot, data2, Colors='blue', /Overplot, BaseLines=data1
   cgBarPlot, data3, Colors='gold', /Overplot, BaseLines=data1+data2
   cgBarPlot, data4, Colors='dark green', /Overplot, BaseLines=data1+data2+data3
   
   ; Add a legend. 
   cgLegend, Title=items, Colors=colors, PSym=15, SymSize=1.75, /Box, $
       Charsize=cgDefCharsize(), Location=[0.20, 0.80], Length=0.0
       
END ;*****************************************************************

; This main program shows how to call the program and produce
; various types of output.

  ; Display the plot in a graphics window.
  MultiBar_Plot
  
  ; Display the plot in a resizeable graphics window.
  cgWindow, 'MultiBar_Plot', WBackground='White', $
     WTitle='MultiBar Plot in a Resizeable Graphics Window'
  
  ; Create a PostScript file.
  cgPS_Open, 'multibar_plot.ps'
  MultiBar_Plot
  cgPS_Close
  
  ; Create a PNG file with a width of 600 pixels.
  cgPS2Raster, 'multibar_plot.ps', /PNG, Width=600

END